from setuptools import setup

setup(name='isotope',
      description='A library to do a stateful logging',
      version='0.0.1a',
      url='https://github.com/codekidX/isotope',
      author='Ashish Shekar',
      author_email='ckrackerx15@gmail.com',
      license='Apache2',
      classifiers=[],
      packages=['isotope'],
      keywords = ['logging', 'logger', 'stateful-logging']
)
